==> haskell-assert-failure-0.1.3.0-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-assert-failure.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 assert-failure
version:              0.1.3.0
visibility:           public
id:                   assert-failure-0.1.3.0-3BDGMadgDY3GCbtrleH58f
key:                  assert-failure-0.1.3.0-3BDGMadgDY3GCbtrleH58f
license:              BSD-3-Clause
maintainer:           Mikolaj Konarski <mikolaj.konarski@funktory.com>
author:               Mikolaj Konarski
homepage:             https://github.com/Mikolaj/assert-failure
synopsis:             Syntactic sugar improving '\''assert'\'' and '\''error'\''
description:
    This library contains syntactic sugar that makes it easier
    to write simple contracts with '\''assert'\'' and '\''error'\''
    and report the values that violate contracts.

category:             Control, Contract
abi:                  80839c05288392fcee794d753ed04e81
exposed:              True
exposed-modules:      Control.Exception.Assert.Sugar
import-dirs:          /usr/lib/ghc-9.4.8/site-local/assert-failure-0.1.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/assert-failure-0.1.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/assert-failure-0.1.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-assert-failure
hs-libraries:         HSassert-failure-0.1.3.0-3BDGMadgDY3GCbtrleH58f
depends:
    base-4.17.2.1 pretty-show-1.10-Ey6CADemQl3EFi7OIHqHDp text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-assert-failure/html/assert-failure.haddock

haddock-html:         /usr/share/doc/haskell-assert-failure/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-assert-failure-0.1.3.0-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-assert-failure.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 assert-failure
version:              0.1.3.0
visibility:           public
id:                   assert-failure-0.1.3.0-AvR5jE5Gn1yHMtzWJbEaJp
key:                  assert-failure-0.1.3.0-AvR5jE5Gn1yHMtzWJbEaJp
license:              BSD-3-Clause
maintainer:           Mikolaj Konarski <mikolaj.konarski@funktory.com>
author:               Mikolaj Konarski
homepage:             https://github.com/Mikolaj/assert-failure
synopsis:             Syntactic sugar improving '\''assert'\'' and '\''error'\''
description:
    This library contains syntactic sugar that makes it easier
    to write simple contracts with '\''assert'\'' and '\''error'\''
    and report the values that violate contracts.

category:             Control, Contract
abi:                  df33c463eae61071d4eb8fd3d798d018
exposed:              True
exposed-modules:      Control.Exception.Assert.Sugar
import-dirs:          /usr/lib/ghc-9.4.8/site-local/assert-failure-0.1.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/assert-failure-0.1.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/assert-failure-0.1.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-assert-failure
hs-libraries:         HSassert-failure-0.1.3.0-AvR5jE5Gn1yHMtzWJbEaJp
depends:
    base-4.17.2.1 pretty-show-1.10-Dwgsrh12Px3tJNgclFhNg text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-assert-failure/html/assert-failure.haddock

haddock-html:         /usr/share/doc/haskell-assert-failure/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
